@@ -64,8 +64,8 @@ function(X, minvi = .03, minsize = default.minsize){
         Z <- abs(sign(-V) * 2 * (sqrt(outer(freqd[,2]+1,freqd[,1]+1)) - sqrt(outer(freqd[,1],freqd[,2]))) /
               sqrt(outer(freqd[,2],freqd[,1],"+") + outer(freqd[,1],freqd[,2],"+")))
         violation.matrix[i,7] <- max(Z)
-        violation.matrix[i,8] <- col(Z)[Z==max(Z)]
-        violation.matrix[i,9] <- row(Z)[Z==max(Z)]
+        violation.matrix[i,8] <- min(col(Z)[Z==max(Z)])
+        violation.matrix[i,9] <- min(row(Z)[Z==max(Z)])
         violation.matrix[i,10] <- sum(sign(Z[Z > 1.6449]))
       }
     }
